import { TZDate } from './tuical/toastui-calendar';

import { addDate, addHours, diffDays, subDate, subtractDate } from './utils';

const today = new TZDate();

/*
* @property {string} [id] - Event id.
* @property {string} [calendarId] - Calendar id.
* @property {string} [title] - Event title.
* @property {string} [body] - Body content of the event.
* @property {string} [isAllday] - Whether the event is all day or not.
* @property {string|number|Date|TZDate} [start] - Start time of the event.
* @property {string|number|Date|TZDate} [end] - End time of the event.
* @property {number} [goingDuration] - Travel time which is taken to go in minutes.
* @property {number} [comingDuration] - Travel time which is taken to come back in minutes.
* @property {string} [location] - Location of the event.
* @property {Array.<string>} [attendees] - Attendees of the event.
* @property {string} [category] - Category of the event. Available categories are 'milestone', 'task', 'time' and 'allday'.
* @property {string} [dueDateClass] - Classification of work events. (before work, before lunch, before work)
* @property {string} [recurrenceRule] - Recurrence rule of the event.
* @property {string} [state] - State of the event. Available states are 'Busy', 'Free'.
* @property {boolean} [isVisible] - Whether the event is visible or not.
* @property {boolean} [isPending] - Whether the event is pending or not.
* @property {boolean} [isFocused] - Whether the event is focused or not.
* @property {boolean} [isReadOnly] - Whether the event is read only or not.
* @property {boolean} [isPrivate] - Whether the event is private or not.
*/

var events = [
  {
    id: '777',
    calendarId: 'work',
    title: '离中考还有 '+diffDays(new TZDate('2023-06-18'), today)+" 天",
    category: 'milestone',
    start: today,
    end: today,
    isReadOnly: true,
  },
  {
    id: '991',
    calendarId: 'work',
    title: '测试吐司日历',
    category: 'time',
    start: addHours(today, 24),
    end: addHours(today, 27),
  },
  {
    id: '992',
    calendarId: 'rest',
    title: '测试完成',
    category: 'milestone',
    start: addDate(today, 5),
    end: addDate(today, 5),
  },
  {
    id: '993',
    calendarId: 'maintain',
    title: '全天维护',
    category: 'allday',
    start: subtractDate(today, 2),
    end: subtractDate(today, 1),
  },
  {
    id: '994',
    calendarId: 'work',
    title: '报表开发',
    category: 'task',
    start: addHours(today, 48),
    end: addHours(today, 51),
  },
];

var calendars = [
  {
    id: 'work',
    name: '工作日',
    backgroundColor: '#9e5fff',
    borderColor: '#9e5fff',
    dragBackgroundColor: '#9e5fff',
  },
  {
    id: 'rest',
    name: '休息日',
    backgroundColor: '#00a9ff',
    borderColor: '#00a9ff',
    dragBackgroundColor: '#00a9ff',
  },
  {
    id: 'maintain',
    name: '维护期',
    backgroundColor: '#55a9ff',
    borderColor: '#55a9ff',
    dragBackgroundColor: '#55a9ff',
  },
];

let param = encodeURIComponent(JSON.stringify({start:'', end:''}));
m3.callFS("/matrix/calendar/load.js", param).then( (res)=>{
  //console.log(res)
  if(res.status == "ok" && res.message && res.message.data && res.message.data.length > 0) {
    for(var i in res.message.data) {
      var dat = res.message.data[i];
      dat.id = events.length;
      // console.log(dat);
      events.push(dat);
    }
  }
}).catch( (err)=>{
  console.error(err);
} );

export var events = events, calendars = calendars;
